@@ -36,11 +36,6 @@
 #include "app.h"
 #include "debug.h"
 
-namespace KShisen
-{
-Q_LOGGING_CATEGORY(KSHISEN_General, "kshisen")
-} // namespace KShisen
-
 static constexpr char description[] = I18N_NOOP("A KDE game similar to Mahjongg");
 
 int main(int argc, char ** argv)
